|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r74251 - sandbox/SOC/2011/checks/libs/checks/example
From: pbristow_at_[hidden]
Date: 2011-09-06 05:07:31
Author: pbristow
Date: 2011-09-06 05:07:29 EDT (Tue, 06 Sep 2011)
New Revision: 74251
URL: http://svn.boost.org/trac/boost/changeset/74251
Log:
Some \details and links added.
Text files modified:
sandbox/SOC/2011/checks/libs/checks/example/checks_tutorial.cpp | 23 +++++++++++++++++------
sandbox/SOC/2011/checks/libs/checks/example/rtn.hpp | 3 +++
sandbox/SOC/2011/checks/libs/checks/example/vin.hpp | 3 +++
3 files changed, 23 insertions(+), 6 deletions(-)
Modified: sandbox/SOC/2011/checks/libs/checks/example/checks_tutorial.cpp
==============================================================================
--- sandbox/SOC/2011/checks/libs/checks/example/rtn.hpp (original)
+++ sandbox/SOC/2011/checks/libs/checks/example/rtn.hpp 2011-09-06 05:07:29 EDT (Tue, 06 Sep 2011)
@@ -2,6 +2,9 @@
//! \file
//! \brief Check and compute the Routing Transit Number (RTN)
//! as an example of implementing a new checksum type.
+/*! \detail Routing Transit Number
+ http://en.wikipedia.org/wiki/Routing_transit_number
+*/
// Copyright Pierre Talbot 2011.
Modified: sandbox/SOC/2011/checks/libs/checks/example/vin.hpp
==============================================================================
--- sandbox/SOC/2011/checks/libs/checks/example/vin.hpp (original)
+++ sandbox/SOC/2011/checks/libs/checks/example/vin.hpp 2011-09-06 05:07:29 EDT (Tue, 06 Sep 2011)
@@ -2,6 +2,9 @@
//! \file
//! \brief Check and compute the Vehicle Identification Number.
//! This is an example of extending the library for a new checksum type.
+/*! \detail Vehicle Identification Number
+ http://en.wikipedia.org/wiki/Vehicle_Identification_Number
+*/
// Copyright Pierre Talbot 2011.
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/SOC/2011/checks/libs/checks/example/checks_tutorial.cpp (original)
+++ sandbox/SOC/2011/checks/libs/checks/example/checks_tutorial.cpp 2011-09-06 05:07:29 EDT (Tue, 06 Sep 2011)
@@ -1,5 +1,14 @@
-//! \file checks_tutorial.cpp
-//! \brief Examples of validating and computing check digit(s) with a homecraft file.
+// checks_tutorial.cpp
+//! \file
+//! \brief Examples of validating and computing check digit(s) with a handcrafted file.
+/*! \detail This extension is very useful as there are hundreds of checksum systems
+ in use worldwide.
+ This example shows how a 'new' checksum system can be programmed
+ by providing custom template parameters and macro constants.
+ The examples chosen are Routing Transit Number
+ http://en.wikipedia.org/wiki/Routing_transit_number (see rtn.hpp)
+ and Vehicle Identification Number (see vin.hpp)
+*/
// Copyright Pierre Talbot 2011.
@@ -14,6 +23,11 @@
// Caution: this file contains Quickbook markup as well as code
// and comments: don't change any of the special comment markups!
+#ifdef _MSC_VER
+# pragma warning (disable : 4127)
+#endif
+
+// Files containing the 'new' checksum definitions.
#include "rtn.hpp"
#include "vin.hpp"
@@ -35,7 +49,6 @@
vin_number = "1M8GDM9AKP042788" ;
std::cout << "The check digit of " << vin_number << " is " << compute_vin ( vin_number) << std::endl ;
return 0;
- //]
}
/*
@@ -49,6 +62,4 @@
//[vin_example_output
The Vehicle Identification Number: 1M8GDM9AXKP042788 is correct.
The check digit of 1M8GDM9AKP042788 is X
-//]
-
-*/
\ No newline at end of file
+*/
Modified: sandbox/SOC/2011/checks/libs/checks/example/rtn.hpp
==============================================================================